==> gcloud-utils-0.1.4.crate: gcloud-utils-0.1.4/README.md <==
<p align="center">
  <a href="https://twitter.com/intent/follow?screen_name=Epic_DAO">
    <img src="https://img.shields.io/twitter/follow/Epic_DAO.svg?label=Follow%20@Epic_DAO" alt="Follow @Epic_DAO" />
  </a>
  <br/>

  <a aria-label="License" href="https://github.com/EpicsDao/epic/blob/master/LICENSE.txt">
    <img alt="" src="https://badgen.net/badge/license/Apache/blue">
  </a>
    <a aria-label="Code of Conduct" href="https://github.com/EpicsDao/epic/blob/master/CODE_OF_CONDUCT.md">
    <img alt="" src="https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg">
  </a>
</p>


## What is gcloud-utils?
Coming soon.

## Dependency
Coming soon.

## Installation
```bash
cargo install gcloud-utils
```

Create `gcp_config.json` config file at first.
```bash
vim gcp_config.json
```

`gcp_config.json`
```bash
{
  "project_id": "epic-app",
  "service_name": "epic-gcp",
  "region": "europe-west4"
}
```

## Usage

```bash
gcu --help
```

## gcloud IAM Setup
Generate Service Account and Get Perimissions.

```bash
gcu iam setup
```

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/EpicsDao/gcloud-utils. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [Apache-2.0 License](https://www.apache.org/licenses/LICENSE-2.0).

## Code of Conduct

Everyone interacting in the SOULs project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/EpicsDao/gcloud-utils/blob/master/CODE_OF_CONDUCT.md).

==> gcloud-utils-0.1.5.crate: gcloud-utils-0.1.5/README.md <==
<p align="center">
  <a href="https://twitter.com/intent/follow?screen_name=Epic_DAO">
    <img src="https://img.shields.io/twitter/follow/Epic_DAO.svg?label=Follow%20@Epic_DAO" alt="Follow @Epic_DAO" />
  </a>
  <br/>

  <a aria-label="License" href="https://github.com/EpicsDao/epic/blob/master/LICENSE.txt">
    <img alt="" src="https://badgen.net/badge/license/Apache/blue">
  </a>
    <a aria-label="Code of Conduct" href="https://github.com/EpicsDao/epic/blob/master/CODE_OF_CONDUCT.md">
    <img alt="" src="https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg">
  </a>
</p>


## What is gcloud-utils?
Coming soon.

## Dependency
Coming soon.

## Installation
```bash
cargo install gcloud-utils
```

Create `gcp_config.json` config file at first.
```bash
vim gcp_config.json
```

`gcp_config.json`
```bash
{
  "project_id": "epic-app",
  "service_name": "epic-gcp",
  "region": "europe-west4"
}
```

## Usage

```bash
gcu --help
```

## Google Cloud IAM Setup
Generate Service Account and Get Perimissions.

```bash
gcu iam setup
```

## Google Cloud Run Deploy
*make sure that you have a Dockerfile and it's successfully build.

```bash
gcu run deploy
```

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/EpicsDao/gcloud-utils. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [Apache-2.0 License](https://www.apache.org/licenses/LICENSE-2.0).

## Code of Conduct

Everyone interacting in the SOULs project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/EpicsDao/gcloud-utils/blob/master/CODE_OF_CONDUCT.md).
